@@ -8,6 +8,6 @@ from syncloud.boot.system import System
 
 if __name__ == '__main__':
 
-    boot = Boot(System(), ['/dev/sda1', '/dev/sdb1'], '/data', 10)
+    boot = Boot(System(), ['/dev/sda1', '/dev/sdb1'], '/data', 10, 'www-data')
     boot.mount_data()
     boot.sync_time()
