@@ -4,8 +4,8 @@ from subprocess import check_output
 
 class System:
 
-    def __init__(self):
-        pass
+    def __init__(self, sys_class_net="/sys/class/net"):
+        self.sys_class_net = sys_class_net
 
     def disk_is_ready(self, disk):
         return self.run(['blkid', disk])
@@ -22,13 +22,21 @@ class System:
         return self.run(chmod) and self.run(chown)
 
     def network_is_up(self, name):
-        with open("/sys/class/net/{}/operstate".format(name), 'r') as f:
-            status = f.read().strip()
-            print "{}: {}".format(name, status)
-            return status == 'up'
+        try:
+            with open("{}{}/operstate".format(self.sys_class_net, name), 'r') as f:
+                status = f.read().strip()
+                print "{}: {}".format(name, status)
+                return status == 'up'
+        except Exception as e:
+            print(e.message)
+            return False
 
     def networks_available(self):
-        return listdir("/sys/class/net")
+        try:
+            return listdir(self.sys_class_net)
+        except Exception as e:
+            print(e.message)
+            return []
 
     def sync_time(self):
         return self.run(['ntpdate', '-u', 'pool.ntp.org'])
